class Nod:

    def __init__(self):
        pass

    def search(self, a, b):
        while (a != 0) and (b != 0):
            if a < b:
                a, b = b, a
            a %= b

        return a + b



import requests

class Weather:
    
    def __init__(self):
        res = requests.get("http://api.openweathermap.org/data/2.5/find", 
        params={
            'q': 'Moscow,RU',
            'type': 'like',
            'units': 'metric',
            'APPID': 'a40a7ba874dd59960768cd44d9f3ced7'
        })
        self.data = res.json()

    def get_description(self):
        return(self.data['list'][1]['weather'][0]['description'])

    def get_temp(self):
        return(self.data['list'][1]['main']['temp'])
    
    def get_wind_speed(self):
        return(self.data['list'][1]['wind']['speed'])

    def get_wind_deg(self):
        return(self.data['list'][1]['wind']['deg'])

    def get_pressure(self):
        return(self.data['list'][1]['main']['pressure'])
    
    def get_humidity(self):
        return(self.data['list'][1]['main']['humidity'])

    def get_feels_like(self):
        return(self.data['list'][1]['main']['feels_like'])


class Es:

    def __init__(self):
        pass

    def search(self, n):
        mask = [1] * (n - 1)
        numbers = list()

        for i in range(2, int(n / 2)):
            t = 2 * i

            while t <= n:
                mask[t - 2] = 0
                t += i
        
        for i in range(len(mask)):
            if mask[i] != 0:
                numbers.append(i + 2)

        return numbers